@@ -162,17 +162,17 @@ typedef union YYSTYPE
 
   char               *string;
   argile_text_t      *text;
-  argile_list_t      *call_list;
+  argrt_list_t       *call_list;
   argile_call_t      *call;
-  argile_list_t      *match_list;
+  argrt_list_t       *match_list;
   argile_match_t     *match;
   argile_cons_t      *cons;
-  argile_list_t      *syn_list;
+  argrt_list_t       *syn_list;
   argile_syntax_t    *syntax;
   argile_syn_param_t *synparm;
-  argile_list_t      *synparm_list;
+  argrt_list_t       *synparm_list;
   argile_syn_list_t  *synlst;
-  argile_list_t      *enm_list;
+  argrt_list_t       *enm_list;
 
 
 
@@ -203,11 +203,12 @@ typedef struct YYLTYPE
 /* Line 343 of yacc.c  */
 #line 106 "./parser.y"
 
- void _set_loc (YYLTYPE *yyloc, argile_loc_t *loc);
+  int yyerror (const char *msg);
+  void _set_loc (YYLTYPE *yyloc, argile_loc_t *loc);
 
 
 /* Line 343 of yacc.c  */
-#line 211 "parser.c"
+#line 212 "parser.c"
 
 #ifdef short
 # undef short
@@ -524,14 +525,14 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   112,   112,   116,   121,   126,   135,   136,   139,   140,
-     143,   153,   165,   170,   181,   186,   191,   199,   207,   215,
-     223,   231,   239,   244,   249,   256,   265,   273,   274,   277,
-     286,   303,   313,   334,   339,   347,   352,   356,   361,   377,
-     382,   387,   392,   397,   408,   415,   421,   439,   444,   451,
-     459,   467,   472,   483,   488,   493,   499,   506,   513,   520,
-     527,   534,   541,   548,   552,   558,   564,   569,   580,   599,
-     604,   615,   638,   648
+       0,   113,   113,   117,   122,   127,   136,   137,   140,   141,
+     144,   154,   166,   171,   182,   187,   192,   200,   208,   216,
+     224,   232,   240,   245,   250,   257,   266,   274,   275,   278,
+     287,   304,   314,   335,   340,   348,   353,   357,   362,   378,
+     383,   388,   393,   398,   409,   416,   422,   440,   445,   452,
+     460,   468,   473,   484,   489,   494,   500,   507,   514,   521,
+     528,   535,   542,   549,   553,   559,   565,   571,   583,   602,
+     607,   618,   641,   651
 };
 #endif
 
@@ -1627,7 +1628,7 @@ yyreduce:
         case 2:
 
 /* Line 1806 of yacc.c  */
-#line 113 "./parser.y"
+#line 114 "./parser.y"
     {
 		    argile_code_append (&argile.main, NULL, NULL);
 		  }
@@ -1636,27 +1637,27 @@ yyreduce:
   case 3:
 
 /* Line 1806 of yacc.c  */
-#line 117 "./parser.y"
+#line 118 "./parser.y"
     {
 		    argile_code_append (&argile.main, NULL,
-					argile_list_start ((yyvsp[(1) - (1)].call_list)));
+					argrt_list_start ((yyvsp[(1) - (1)].call_list)));
 		  }
     break;
 
   case 4:
 
 /* Line 1806 of yacc.c  */
-#line 122 "./parser.y"
+#line 123 "./parser.y"
     {
 		    argile_code_append (&argile.main, NULL,
-					argile_list_start ((yyvsp[(2) - (2)].call_list)));
+					argrt_list_start ((yyvsp[(2) - (2)].call_list)));
 		  }
     break;
 
   case 5:
 
 /* Line 1806 of yacc.c  */
-#line 127 "./parser.y"
+#line 128 "./parser.y"
     {
 		    argile_die ("parse error at %d:%d-%d:%d",
 				(yylsp[(1) - (1)]).first_line, (yylsp[(1) - (1)]).first_column,
@@ -1668,14 +1669,14 @@ yyreduce:
   case 10:
 
 /* Line 1806 of yacc.c  */
-#line 144 "./parser.y"
+#line 145 "./parser.y"
     {
 		    argile_call_t *call;
-		    call = argile_call_new (NULL, argile_list_start ((yyvsp[(1) - (2)].match_list)));
+		    call = argile_call_new (NULL, argrt_list_start ((yyvsp[(1) - (2)].match_list)));
 		    argile_add_leak (call);
 		    argile.numcalls++;
 		    _set_loc (&(yylsp[(1) - (2)]), &call->loc);
-		    (yyval.call_list) = argile_list_new (call, argile_call_del);
+		    (yyval.call_list) = argrt_list_new (call, argile_call_del);
 		    argile_add_leak ((yyval.call_list));
 		  }
     break;
@@ -1683,25 +1684,25 @@ yyreduce:
   case 11:
 
 /* Line 1806 of yacc.c  */
-#line 154 "./parser.y"
+#line 155 "./parser.y"
     {
 		    argile_call_t *call;
-		    call = argile_call_new (NULL, argile_list_start ((yyvsp[(2) - (3)].match_list)));
+		    call = argile_call_new (NULL, argrt_list_start ((yyvsp[(2) - (3)].match_list)));
 		    argile_add_leak (call);
 		    argile.numcalls++;
 		    _set_loc (&(yylsp[(2) - (3)]), &call->loc);
-		    (yyval.call_list) = argile_list_new (call, argile_call_del);
+		    (yyval.call_list) = argrt_list_new (call, argile_call_del);
 		    argile_add_leak ((yyval.call_list));
-		    argile_list_link ((yyvsp[(1) - (3)].call_list), (yyval.call_list));
+		    argrt_list_link ((yyvsp[(1) - (3)].call_list), (yyval.call_list));
 		  }
     break;
 
   case 12:
 
 /* Line 1806 of yacc.c  */
-#line 166 "./parser.y"
+#line 167 "./parser.y"
     {
-		    (yyval.match_list) = argile_list_new ((yyvsp[(1) - (1)].match), argile_match_del);
+		    (yyval.match_list) = argrt_list_new ((yyvsp[(1) - (1)].match), argile_match_del);
 		    argile_add_leak ((yyval.match_list));
 		  }
     break;
@@ -1709,13 +1710,13 @@ yyreduce:
   case 13:
 
 /* Line 1806 of yacc.c  */
-#line 171 "./parser.y"
+#line 172 "./parser.y"
     {
-		    argile_list_t *lst;
+		    argrt_list_t *lst;
 
-		    lst = argile_list_new ((yyvsp[(2) - (2)].match), argile_match_del);
+		    lst = argrt_list_new ((yyvsp[(2) - (2)].match), argile_match_del);
 		    argile_add_leak (lst);
-		    argile_list_link ((yyvsp[(1) - (2)].match_list), lst);
+		    argrt_list_link ((yyvsp[(1) - (2)].match_list), lst);
 		    (yyval.match_list) = lst;
 		  }
     break;
@@ -1723,7 +1724,7 @@ yyreduce:
   case 14:
 
 /* Line 1806 of yacc.c  */
-#line 182 "./parser.y"
+#line 183 "./parser.y"
     {
 		    (yyval.match) = argile_match_new (ARGILE_MATCH_WORD, (yyvsp[(1) - (1)].string));
 		    argile_add_leak ((yyval.match));
@@ -1733,7 +1734,7 @@ yyreduce:
   case 15:
 
 /* Line 1806 of yacc.c  */
-#line 187 "./parser.y"
+#line 188 "./parser.y"
     {
 		    (yyval.match) = argile_match_new (ARGILE_MATCH_OP, (yyvsp[(1) - (1)].string));
 		    argile_add_leak ((yyval.match));
@@ -1743,7 +1744,7 @@ yyreduce:
   case 16:
 
 /* Line 1806 of yacc.c  */
-#line 192 "./parser.y"
+#line 193 "./parser.y"
     {
 		    (yyval.match) = argile_match_new (ARGILE_MATCH_CONS,
 					   argile_cons_new (ARGILE_CONS_HEX,
@@ -1756,7 +1757,7 @@ yyreduce:
   case 17:
 
 /* Line 1806 of yacc.c  */
-#line 200 "./parser.y"
+#line 201 "./parser.y"
     {
 		    (yyval.match) = argile_match_new (ARGILE_MATCH_CONS,
 					   argile_cons_new (ARGILE_CONS_DEC,
@@ -1769,7 +1770,7 @@ yyreduce:
   case 18:
 
 /* Line 1806 of yacc.c  */
-#line 208 "./parser.y"
+#line 209 "./parser.y"
     {
 		    (yyval.match) = argile_match_new (ARGILE_MATCH_CONS,
 					   argile_cons_new (ARGILE_CONS_OCT,
@@ -1782,7 +1783,7 @@ yyreduce:
   case 19:
 
 /* Line 1806 of yacc.c  */
-#line 216 "./parser.y"
+#line 217 "./parser.y"
     {
 		    (yyval.match) = argile_match_new (ARGILE_MATCH_CONS,
 					   argile_cons_new (ARGILE_CONS_BIN,
@@ -1795,7 +1796,7 @@ yyreduce:
   case 20:
 
 /* Line 1806 of yacc.c  */
-#line 224 "./parser.y"
+#line 225 "./parser.y"
     {
 		    (yyval.match) = argile_match_new (ARGILE_MATCH_CONS,
 					   argile_cons_new (ARGILE_CONS_REAL,
@@ -1808,7 +1809,7 @@ yyreduce:
   case 21:
 
 /* Line 1806 of yacc.c  */
-#line 232 "./parser.y"
+#line 233 "./parser.y"
     {
 		    (yyval.match) = argile_match_new (ARGILE_MATCH_CONS,
 					   argile_cons_new (ARGILE_CONS_TEXT,
@@ -1821,7 +1822,7 @@ yyreduce:
   case 22:
 
 /* Line 1806 of yacc.c  */
-#line 240 "./parser.y"
+#line 241 "./parser.y"
     {
 		    (yyval.match) = argile_match_new (ARGILE_MATCH_SUBCALL, (yyvsp[(1) - (1)].call));
 		    argile_add_leak ((yyval.match));
@@ -1831,7 +1832,7 @@ yyreduce:
   case 23:
 
 /* Line 1806 of yacc.c  */
-#line 245 "./parser.y"
+#line 246 "./parser.y"
     {
 		    (yyval.match) = argile_match_new (ARGILE_MATCH_CONS, (yyvsp[(1) - (1)].cons));
 		    argile_add_leak ((yyval.match));
@@ -1841,7 +1842,7 @@ yyreduce:
   case 24:
 
 /* Line 1806 of yacc.c  */
-#line 250 "./parser.y"
+#line 251 "./parser.y"
     {
 		    (yyval.match) = argile_match_new (ARGILE_MATCH_CONS, (yyvsp[(1) - (1)].cons));
 		    argile_add_leak ((yyval.match));
@@ -1851,7 +1852,7 @@ yyreduce:
   case 25:
 
 /* Line 1806 of yacc.c  */
-#line 257 "./parser.y"
+#line 258 "./parser.y"
     {
 		    (yyval.call) = argile_call_new (NULL, NULL);
 		    (yyval.call)->loc.start.row = (yylsp[(1) - (2)]).first_line;
@@ -1865,9 +1866,9 @@ yyreduce:
   case 26:
 
 /* Line 1806 of yacc.c  */
-#line 266 "./parser.y"
+#line 267 "./parser.y"
     {
-		    (yyval.call) = argile_call_new (NULL, argile_list_start ((yyvsp[(2) - (3)].match_list)));
+		    (yyval.call) = argile_call_new (NULL, argrt_list_start ((yyvsp[(2) - (3)].match_list)));
 		    _set_loc (&(yylsp[(2) - (3)]), &(yyval.call)->loc);
 		    argile_add_leak ((yyval.call));
 		  }
@@ -1876,7 +1877,7 @@ yyreduce:
   case 29:
 
 /* Line 1806 of yacc.c  */
-#line 278 "./parser.y"
+#line 279 "./parser.y"
     {
 		    (yyval.cons) = argile_cons_new (ARGILE_CONS_CODE,
 					  argile_code_new (NULL, NULL));
@@ -1890,15 +1891,15 @@ yyreduce:
   case 30:
 
 /* Line 1806 of yacc.c  */
-#line 287 "./parser.y"
+#line 288 "./parser.y"
     {
-		    argile_list_t *calls;
+		    argrt_list_t *calls;
 		    argile_call_t *call;
-		    call = argile_call_new (NULL, argile_list_start ((yyvsp[(2) - (3)].match_list)));
+		    call = argile_call_new (NULL, argrt_list_start ((yyvsp[(2) - (3)].match_list)));
 		    argile.numcalls++;
 		    argile_add_leak (call);
 		    _set_loc (&(yylsp[(2) - (3)]), &call->loc);
-		    calls = argile_list_new (call, argile_call_del);
+		    calls = argrt_list_new (call, argile_call_del);
 		    (yyval.cons) = argile_cons_new (ARGILE_CONS_CODE,
 					  argile_code_new (NULL, calls));
 		    argile_add_leak ((yyval.cons));
@@ -1912,11 +1913,11 @@ yyreduce:
   case 31:
 
 /* Line 1806 of yacc.c  */
-#line 304 "./parser.y"
+#line 305 "./parser.y"
     {
 		    (yyval.cons) = argile_cons_new (ARGILE_CONS_CODE,
 					  argile_code_new (NULL,
-							   argile_list_start ((yyvsp[(2) - (3)].call_list))));
+							   argrt_list_start ((yyvsp[(2) - (3)].call_list))));
 		    argile_add_leak ((yyval.cons));
 		    argile_add_leak ((yyval.cons)->cvalue.code);
 		    if ((yyval.cons)->cvalue.code->input)
@@ -1927,20 +1928,20 @@ yyreduce:
   case 32:
 
 /* Line 1806 of yacc.c  */
-#line 314 "./parser.y"
+#line 315 "./parser.y"
     {
-		    argile_list_t *lst;
+		    argrt_list_t *lst;
 		    argile_call_t *call = argile_call_new (NULL,
-							   argile_list_start ((yyvsp[(3) - (4)].match_list)));
+							   argrt_list_start ((yyvsp[(3) - (4)].match_list)));
 		    argile.numcalls++;
 		    argile_add_leak (call);
 		    _set_loc (&(yylsp[(3) - (4)]), &call->loc);
-		    lst = argile_list_new (call, argile_call_del);
+		    lst = argrt_list_new (call, argile_call_del);
 		    argile_add_leak (lst);
-		    argile_list_link ((yyvsp[(2) - (4)].call_list), lst);
+		    argrt_list_link ((yyvsp[(2) - (4)].call_list), lst);
 		    (yyval.cons) = argile_cons_new (ARGILE_CONS_CODE,
 					  argile_code_new (NULL,
-							   argile_list_start ((yyvsp[(2) - (4)].call_list))));
+							   argrt_list_start ((yyvsp[(2) - (4)].call_list))));
 		    argile_add_leak ((yyval.cons));
 		    argile_add_leak ((yyval.cons)->cvalue.code);
 		    if ((yyval.cons)->cvalue.code->input)
@@ -1951,7 +1952,7 @@ yyreduce:
   case 33:
 
 /* Line 1806 of yacc.c  */
-#line 335 "./parser.y"
+#line 336 "./parser.y"
     {
 		    (yyval.cons) = argile_cons_new (ARGILE_CONS_SYNTAX, NULL);
 		    argile_add_leak ((yyval.cons));
@@ -1961,10 +1962,10 @@ yyreduce:
   case 34:
 
 /* Line 1806 of yacc.c  */
-#line 340 "./parser.y"
+#line 341 "./parser.y"
     {
 		    (yyval.cons) = argile_cons_new (ARGILE_CONS_SYNTAX,
-					  argile_list_start ((yyvsp[(2) - (3)].syn_list)));
+					  argrt_list_start ((yyvsp[(2) - (3)].syn_list)));
 		    argile_add_leak ((yyval.cons));
 		  }
     break;
@@ -1972,9 +1973,9 @@ yyreduce:
   case 35:
 
 /* Line 1806 of yacc.c  */
-#line 348 "./parser.y"
+#line 349 "./parser.y"
     {
-		    (yyval.syn_list) = argile_list_new ((yyvsp[(1) - (1)].syntax), argile_syntax_del);
+		    (yyval.syn_list) = argrt_list_new ((yyvsp[(1) - (1)].syntax), argile_syntax_del);
 		    argile_add_leak ((yyval.syn_list));
 		  }
     break;
@@ -1982,7 +1983,7 @@ yyreduce:
   case 36:
 
 /* Line 1806 of yacc.c  */
-#line 353 "./parser.y"
+#line 354 "./parser.y"
     {
 		    (yyval.syn_list) = (yyvsp[(1) - (1)].syn_list);
 		  }
@@ -1991,9 +1992,9 @@ yyreduce:
   case 37:
 
 /* Line 1806 of yacc.c  */
-#line 357 "./parser.y"
+#line 358 "./parser.y"
     {
-		    argile_list_link ((yyvsp[(1) - (2)].syn_list), argile_list_start ((yyvsp[(2) - (2)].syn_list)));
+		    argrt_list_link ((yyvsp[(1) - (2)].syn_list), argrt_list_start ((yyvsp[(2) - (2)].syn_list)));
 		    (yyval.syn_list) = (yyvsp[(2) - (2)].syn_list);
 		  }
     break;
@@ -2001,15 +2002,15 @@ yyreduce:
   case 38:
 
 /* Line 1806 of yacc.c  */
-#line 362 "./parser.y"
+#line 363 "./parser.y"
     {
-		    argile_list_t *lst;
+		    argrt_list_t *lst;
 
 		    if ((yyvsp[(2) - (2)].syntax))
 		      {
-			lst = argile_list_new ((yyvsp[(2) - (2)].syntax), argile_syntax_del);
+			lst = argrt_list_new ((yyvsp[(2) - (2)].syntax), argile_syntax_del);
 			argile_add_leak (lst);
-			argile_list_link ((yyvsp[(1) - (2)].syn_list), lst);
+			argrt_list_link ((yyvsp[(1) - (2)].syn_list), lst);
 			(yyval.syn_list) = lst;
 		      }
 		    else
@@ -2020,7 +2021,7 @@ yyreduce:
   case 39:
 
 /* Line 1806 of yacc.c  */
-#line 378 "./parser.y"
+#line 379 "./parser.y"
     {
 		    (yyval.syntax) = argile_syntax_new (ARGILE_SYN_WORD, (yyvsp[(1) - (1)].string));
 		    argile_add_leak ((yyval.syntax));
@@ -2030,7 +2031,7 @@ yyreduce:
   case 40:
 
 /* Line 1806 of yacc.c  */
-#line 383 "./parser.y"
+#line 384 "./parser.y"
     {
 		    (yyval.syntax) = argile_syntax_new (ARGILE_SYN_OP, (yyvsp[(1) - (1)].string));
 		    argile_add_leak ((yyval.syntax));
@@ -2040,7 +2041,7 @@ yyreduce:
   case 41:
 
 /* Line 1806 of yacc.c  */
-#line 388 "./parser.y"
+#line 389 "./parser.y"
     {
 		    (yyval.syntax) = argile_syntax_new (ARGILE_SYN_PARAM, (yyvsp[(1) - (1)].synparm));
 		    argile_add_leak ((yyval.syntax));
@@ -2050,7 +2051,7 @@ yyreduce:
   case 42:
 
 /* Line 1806 of yacc.c  */
-#line 393 "./parser.y"
+#line 394 "./parser.y"
     {
 		    (yyval.syntax) = argile_syntax_new (ARGILE_SYN_OPTION, (yyvsp[(1) - (1)].syn_list));
 		    argile_add_leak ((yyval.syntax));
@@ -2060,10 +2061,10 @@ yyreduce:
   case 43:
 
 /* Line 1806 of yacc.c  */
-#line 398 "./parser.y"
+#line 399 "./parser.y"
     {
-		    argile_list_t *lst = (yyvsp[(1) - (1)].enm_list);
-		    if (argile_list_count (lst) < 2)
+		    argrt_list_t *lst = (yyvsp[(1) - (1)].enm_list);
+		    if (argrt_list_count (lst) < 2)
 		      {
 			argile_die ("length of syntax enumeration < 2");
 			YYERROR;
@@ -2076,7 +2077,7 @@ yyreduce:
   case 44:
 
 /* Line 1806 of yacc.c  */
-#line 409 "./parser.y"
+#line 410 "./parser.y"
     {
 		    (yyval.syntax) = argile_syntax_new (ARGILE_SYN_LIST, (yyvsp[(1) - (1)].synlst));
 		    argile_add_leak ((yyval.syntax));
@@ -2086,7 +2087,7 @@ yyreduce:
   case 45:
 
 /* Line 1806 of yacc.c  */
-#line 416 "./parser.y"
+#line 417 "./parser.y"
     {
 		    (yyval.synparm) = (yyvsp[(2) - (3)].synparm);
 		  }
@@ -2095,30 +2096,30 @@ yyreduce:
   case 46:
 
 /* Line 1806 of yacc.c  */
-#line 422 "./parser.y"
+#line 423 "./parser.y"
     {
-		    argile_list_t *lst, *params = NULL;
+		    argrt_list_t *lst, *params = NULL;
 		    for (lst = (yyvsp[(2) - (3)].synparm_list); lst; lst = lst->prev)
 		      {
 			argile_rm_leak (lst);
-			argile_list_prepend (&params,
-					     argile_list_new (argile_syntax_new (ARGILE_SYN_PARAM,
-										 lst->data.u_anything),
+			argrt_list_prepend (&params,
+					     argrt_list_new (argile_syntax_new (ARGILE_SYN_PARAM,
+										 lst->data.any),
 							      argile_syntax_del));
 			argile_add_leak (params);
-			argile_add_leak (params->data.u_anything);
+			argile_add_leak (params->data.any);
 		      }
-		    argile_list_del ((yyvsp[(2) - (3)].synparm_list));
-		    (yyval.syn_list) = argile_list_end (params);
+		    argrt_list_delete_all ((yyvsp[(2) - (3)].synparm_list));
+		    (yyval.syn_list) = argrt_list_end (params);
 		  }
     break;
 
   case 47:
 
 /* Line 1806 of yacc.c  */
-#line 440 "./parser.y"
+#line 441 "./parser.y"
     {
-		    (yyval.synparm) = argile_syn_param_new (argile_list_start ((yyvsp[(1) - (3)].match_list)), (yyvsp[(3) - (3)].match));
+		    (yyval.synparm) = argile_syn_param_new (argrt_list_start ((yyvsp[(1) - (3)].match_list)), (yyvsp[(3) - (3)].match));
 		    argile_add_leak ((yyval.synparm));
 		  }
     break;
@@ -2126,9 +2127,9 @@ yyreduce:
   case 48:
 
 /* Line 1806 of yacc.c  */
-#line 445 "./parser.y"
+#line 446 "./parser.y"
     {
-		    (yyval.synparm) = argile_syn_param_new (argile_list_start ((yyvsp[(1) - (1)].match_list)), NULL);
+		    (yyval.synparm) = argile_syn_param_new (argrt_list_start ((yyvsp[(1) - (1)].match_list)), NULL);
 		    argile_add_leak ((yyval.synparm));
 		  }
     break;
@@ -2136,33 +2137,33 @@ yyreduce:
   case 49:
 
 /* Line 1806 of yacc.c  */
-#line 452 "./parser.y"
+#line 453 "./parser.y"
     {
-		    argile_list_t *first = argile_list_new ((yyvsp[(1) - (3)].synparm), NULL);
+		    argrt_list_t *first = argrt_list_new ((yyvsp[(1) - (3)].synparm), NULL);
 		    argile_add_leak (first);
-		    (yyval.synparm_list) = argile_list_new ((yyvsp[(3) - (3)].synparm), NULL);
+		    (yyval.synparm_list) = argrt_list_new ((yyvsp[(3) - (3)].synparm), NULL);
 		    argile_add_leak ((yyval.synparm_list));
-		    argile_list_link (first, (yyval.synparm_list));
+		    argrt_list_link (first, (yyval.synparm_list));
 		  }
     break;
 
   case 50:
 
 /* Line 1806 of yacc.c  */
-#line 460 "./parser.y"
+#line 461 "./parser.y"
     {
-		    (yyval.synparm_list) = argile_list_new ((yyvsp[(3) - (3)].synparm), NULL);
+		    (yyval.synparm_list) = argrt_list_new ((yyvsp[(3) - (3)].synparm), NULL);
 		    argile_add_leak ((yyval.synparm_list));
-		    argile_list_link ((yyvsp[(1) - (3)].synparm_list), (yyval.synparm_list));
+		    argrt_list_link ((yyvsp[(1) - (3)].synparm_list), (yyval.synparm_list));
 		  }
     break;
 
   case 51:
 
 /* Line 1806 of yacc.c  */
-#line 468 "./parser.y"
+#line 469 "./parser.y"
     {
-		    (yyval.match_list) = argile_list_new ((yyvsp[(1) - (1)].match), argile_match_del);
+		    (yyval.match_list) = argrt_list_new ((yyvsp[(1) - (1)].match), argile_match_del);
 		    argile_add_leak ((yyval.match_list));
 		  }
     break;
@@ -2170,13 +2171,13 @@ yyreduce:
   case 52:
 
 /* Line 1806 of yacc.c  */
-#line 473 "./parser.y"
+#line 474 "./parser.y"
     {
-		    argile_list_t *lst;
+		    argrt_list_t *lst;
 
-		    lst = argile_list_new ((yyvsp[(2) - (2)].match), argile_match_del);
+		    lst = argrt_list_new ((yyvsp[(2) - (2)].match), argile_match_del);
 		    argile_add_leak (lst);
-		    argile_list_link ((yyvsp[(1) - (2)].match_list), lst);
+		    argrt_list_link ((yyvsp[(1) - (2)].match_list), lst);
 		    (yyval.match_list) = lst;
 		  }
     break;
@@ -2184,7 +2185,7 @@ yyreduce:
   case 53:
 
 /* Line 1806 of yacc.c  */
-#line 484 "./parser.y"
+#line 485 "./parser.y"
     {
 		    (yyval.match) = argile_match_new (ARGILE_MATCH_WORD, (yyvsp[(1) - (1)].string));
 		    argile_add_leak ((yyval.match));
@@ -2194,7 +2195,7 @@ yyreduce:
   case 54:
 
 /* Line 1806 of yacc.c  */
-#line 489 "./parser.y"
+#line 490 "./parser.y"
     {
 		    (yyval.match) = argile_match_new (ARGILE_MATCH_OP, (yyvsp[(1) - (1)].string));
 		    argile_add_leak ((yyval.match));
@@ -2204,7 +2205,7 @@ yyreduce:
   case 55:
 
 /* Line 1806 of yacc.c  */
-#line 494 "./parser.y"
+#line 495 "./parser.y"
     {
 		    (yyval.match) = (yyvsp[(1) - (1)].match);
 		  }
@@ -2213,7 +2214,7 @@ yyreduce:
   case 56:
 
 /* Line 1806 of yacc.c  */
-#line 500 "./parser.y"
+#line 501 "./parser.y"
     {
 		    (yyval.match) = argile_match_new (ARGILE_MATCH_CONS,
 					   argile_cons_new (ARGILE_CONS_HEX, (yyvsp[(1) - (1)].string)));
@@ -2225,7 +2226,7 @@ yyreduce:
   case 57:
 
 /* Line 1806 of yacc.c  */
-#line 507 "./parser.y"
+#line 508 "./parser.y"
     {
 		    (yyval.match) = argile_match_new (ARGILE_MATCH_CONS,
 					   argile_cons_new (ARGILE_CONS_DEC, (yyvsp[(1) - (1)].string)));
@@ -2237,7 +2238,7 @@ yyreduce:
   case 58:
 
 /* Line 1806 of yacc.c  */
-#line 514 "./parser.y"
+#line 515 "./parser.y"
     {
 		    (yyval.match) = argile_match_new (ARGILE_MATCH_CONS,
 					   argile_cons_new (ARGILE_CONS_OCT, (yyvsp[(1) - (1)].string)));
@@ -2249,7 +2250,7 @@ yyreduce:
   case 59:
 
 /* Line 1806 of yacc.c  */
-#line 521 "./parser.y"
+#line 522 "./parser.y"
     {
 		    (yyval.match) = argile_match_new (ARGILE_MATCH_CONS,
 					   argile_cons_new (ARGILE_CONS_BIN, (yyvsp[(1) - (1)].string)));
@@ -2261,7 +2262,7 @@ yyreduce:
   case 60:
 
 /* Line 1806 of yacc.c  */
-#line 528 "./parser.y"
+#line 529 "./parser.y"
     {
 		    (yyval.match) = argile_match_new (ARGILE_MATCH_CONS,
 					   argile_cons_new (ARGILE_CONS_REAL, (yyvsp[(1) - (1)].string)));
@@ -2273,7 +2274,7 @@ yyreduce:
   case 61:
 
 /* Line 1806 of yacc.c  */
-#line 535 "./parser.y"
+#line 536 "./parser.y"
     {
 		    (yyval.match) = argile_match_new (ARGILE_MATCH_CONS,
 					   argile_cons_new (ARGILE_CONS_TEXT, (yyvsp[(1) - (1)].text)));
@@ -2285,7 +2286,7 @@ yyreduce:
   case 62:
 
 /* Line 1806 of yacc.c  */
-#line 542 "./parser.y"
+#line 543 "./parser.y"
     {
 		    (yyval.match) = argile_match_new (ARGILE_MATCH_SUBCALL, (yyvsp[(1) - (1)].call));
 		    argile_add_leak ((yyval.match));
@@ -2295,36 +2296,37 @@ yyreduce:
   case 63:
 
 /* Line 1806 of yacc.c  */
-#line 549 "./parser.y"
+#line 550 "./parser.y"
     {
-		    (yyval.syn_list) = argile_list_start ((yyvsp[(2) - (3)].syn_list));
+		    (yyval.syn_list) = argrt_list_start ((yyvsp[(2) - (3)].syn_list));
 		  }
     break;
 
   case 64:
 
 /* Line 1806 of yacc.c  */
-#line 553 "./parser.y"
+#line 554 "./parser.y"
     {
-		    (yyval.syn_list) = argile_list_start ((yyvsp[(2) - (3)].syn_list));
+		    (yyval.syn_list) = argrt_list_start ((yyvsp[(2) - (3)].syn_list));
 		  }
     break;
 
   case 65:
 
 /* Line 1806 of yacc.c  */
-#line 559 "./parser.y"
+#line 560 "./parser.y"
     {
-		    (yyval.enm_list) = argile_list_start ((yyvsp[(2) - (3)].enm_list));
+		    (yyval.enm_list) = argrt_list_start ((yyvsp[(2) - (3)].enm_list));
 		  }
     break;
 
   case 66:
 
 /* Line 1806 of yacc.c  */
-#line 565 "./parser.y"
+#line 566 "./parser.y"
     {
-		    (yyval.enm_list) = argile_list_new (argile_list_start ((yyvsp[(1) - (1)].syn_list)), argile_list_del);
+		    (yyval.enm_list) = argrt_list_new (argrt_list_start ((yyvsp[(1) - (1)].syn_list)),
+					 argrt_list_delete_all);
 		    argile_add_leak ((yyval.enm_list));
 		  }
     break;
@@ -2332,13 +2334,14 @@ yyreduce:
   case 67:
 
 /* Line 1806 of yacc.c  */
-#line 570 "./parser.y"
+#line 572 "./parser.y"
     {
-		    argile_list_t *lst;
+		    argrt_list_t *lst;
 
-		    lst = argile_list_new (argile_list_start ((yyvsp[(3) - (3)].syn_list)), argile_list_del);
+		    lst = argrt_list_new (argrt_list_start ((yyvsp[(3) - (3)].syn_list)),
+					  argrt_list_delete_all);
 		    argile_add_leak (lst);
-		    argile_list_link ((yyvsp[(1) - (3)].enm_list), lst);
+		    argrt_list_link ((yyvsp[(1) - (3)].enm_list), lst);
 		    (yyval.enm_list) = lst;
 		  }
     break;
@@ -2346,9 +2349,9 @@ yyreduce:
   case 68:
 
 /* Line 1806 of yacc.c  */
-#line 581 "./parser.y"
+#line 584 "./parser.y"
     {
-		    argile_list_t *ls;
+		    argrt_list_t *ls;
 		    argile_syntax_t *s;
 		    argile_syn_param_t *sp;
 
@@ -2357,7 +2360,7 @@ yyreduce:
 		    sp->pseudo = 1;
 		    sp->comp = 1;
 		    s = argile_syntax_new (ARGILE_SYN_PARAM, sp);
-		    ls = argile_list_new (s, argile_syntax_del);
+		    ls = argrt_list_new (s, argile_syntax_del);
 		    (yyval.synlst) = argile_syn_list_new (ls, 0, 0);
 		    (yyval.synlst)->pseudoempty = 1;
 		    argile_add_leak (sp);
@@ -2370,9 +2373,9 @@ yyreduce:
   case 69:
 
 /* Line 1806 of yacc.c  */
-#line 600 "./parser.y"
+#line 603 "./parser.y"
     {
-		    (yyval.synlst) = argile_syn_list_new (argile_list_start ((yyvsp[(2) - (4)].syn_list)), 0, 0);
+		    (yyval.synlst) = argile_syn_list_new (argrt_list_start ((yyvsp[(2) - (4)].syn_list)), 0, 0);
 		    argile_add_leak ((yyval.synlst));
 		  }
     break;
@@ -2380,13 +2383,13 @@ yyreduce:
   case 70:
 
 /* Line 1806 of yacc.c  */
-#line 605 "./parser.y"
+#line 608 "./parser.y"
     {
 		    argile_syn_list_t *lst;
 
 		    lst = (yyvsp[(4) - (5)].synlst);
 		    if (lst)
-		      lst->sub = argile_list_start ((yyvsp[(2) - (5)].syn_list));
+		      lst->sub = argrt_list_start ((yyvsp[(2) - (5)].syn_list));
 		    (yyval.synlst) = lst;
 		  }
     break;
@@ -2394,7 +2397,7 @@ yyreduce:
   case 71:
 
 /* Line 1806 of yacc.c  */
-#line 616 "./parser.y"
+#line 619 "./parser.y"
     {
 		    int min, max;
 
@@ -2402,8 +2405,8 @@ yyreduce:
 		    max = atoi ((yyvsp[(3) - (3)].string));
 		    argile_rm_leak ((yyvsp[(1) - (3)].string));
 		    argile_rm_leak ((yyvsp[(3) - (3)].string));
-		    argile_dbg_free ((yyvsp[(1) - (3)].string));
-		    argile_dbg_free ((yyvsp[(3) - (3)].string));
+		    ARGRT_free ((yyvsp[(1) - (3)].string));
+		    ARGRT_free ((yyvsp[(3) - (3)].string));
 		    if (!max)
 		      {
 			argile_die ("null syntax list maximum counter");
@@ -2422,13 +2425,13 @@ yyreduce:
   case 72:
 
 /* Line 1806 of yacc.c  */
-#line 639 "./parser.y"
+#line 642 "./parser.y"
     {
 		    int min;
 
 		    min = atoi ((yyvsp[(1) - (2)].string));
 		    argile_rm_leak ((yyvsp[(1) - (2)].string));
-		    argile_dbg_free ((yyvsp[(1) - (2)].string));
+		    ARGRT_free ((yyvsp[(1) - (2)].string));
 		    (yyval.synlst) = argile_syn_list_new (NULL, min, 0);
 		    argile_add_leak ((yyval.synlst));
 		  }
@@ -2437,13 +2440,13 @@ yyreduce:
   case 73:
 
 /* Line 1806 of yacc.c  */
-#line 649 "./parser.y"
+#line 652 "./parser.y"
     {
 		    int num;
 
 		    num = atoi ((yyvsp[(1) - (1)].string));
 		    argile_rm_leak ((yyvsp[(1) - (1)].string));
-		    argile_dbg_free ((yyvsp[(1) - (1)].string));
+		    ARGRT_free ((yyvsp[(1) - (1)].string));
 		    if (!num)
 		      {
 			argile_die ("null syntax list exact counter");
@@ -2457,7 +2460,7 @@ yyreduce:
 
 
 /* Line 1806 of yacc.c  */
-#line 2461 "parser.c"
+#line 2464 "parser.c"
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2695,11 +2698,11 @@ yyreturn:
 
 
 /* Line 2067 of yacc.c  */
-#line 665 "./parser.y"
+#line 668 "./parser.y"
 
 
 int
-yyerror (char *msg)
+yyerror (const char *msg)
 {
   argile_die ("%s", msg);
   return 0;
